@@ -413,8 +413,6 @@ def test_multiple_list_slicing():
     assert_eq(x[:, [0, 1, 2]][[0, 1]], a[:, [0, 1, 2]][[0, 1]])
 
 
-@pytest.mark.skipif(np.__version__ < '1.13.0',
-                    reason='boolean lists are not treated as boolean indexes')
 def test_boolean_list_slicing():
     with pytest.raises(IndexError):
         da.asarray(range(2))[[True]]
@@ -820,3 +818,13 @@ def test_setitem_with_different_chunks_preserves_shape(params):
 def test_gh3579():
     assert_eq(np.arange(10)[0::-1], da.arange(10, chunks=3)[0::-1])
     assert_eq(np.arange(10)[::-1], da.arange(10, chunks=3)[::-1])
+
+
+@pytest.mark.parametrize('lock', [True, False])
+@pytest.mark.parametrize('asarray', [True, False])
+@pytest.mark.parametrize('fancy', [True, False])
+def test_gh4043(lock, asarray, fancy):
+    a1 = da.from_array(np.zeros(3,), chunks=1, asarray=asarray, lock=lock, fancy=fancy)
+    a2 = da.from_array(np.ones(3,), chunks=1, asarray=asarray, lock=lock, fancy=fancy)
+    al = da.stack([a1, a2])
+    assert_eq(al, al)
