@@ -263,9 +263,9 @@ def unpack_collections(*args, **kwargs):
             typ = list if isinstance(expr, Iterator) else type(expr)
             if typ in (list, tuple, set):
                 tsk = (typ, [_unpack(i) for i in expr])
-            elif typ is dict:
-                tsk = (dict, [[_unpack(k), _unpack(v)]
-                              for k, v in expr.items()])
+            elif typ in (dict, OrderedDict):
+                tsk = (typ, [[_unpack(k), _unpack(v)]
+                             for k, v in expr.items()])
             elif is_dataclass(expr):
                 tsk = (apply, typ, (), (dict,
                        [[f.name, _unpack(getattr(expr, f.name))] for f in
@@ -450,10 +450,17 @@ def visualize(*args, **kwargs):
     filename = kwargs.pop('filename', 'mydask')
     optimize_graph = kwargs.pop('optimize_graph', False)
 
-    dsks = [arg for arg in args if isinstance(arg, Mapping)]
-    args = [arg for arg in args if is_dask_collection(arg)]
+    args2 = []
+    for arg in args:
+        if isinstance(arg, (list, tuple, set)):
+            args2.extend(arg)
+        else:
+            args2.append(arg)
 
-    dsk = dict(collections_to_dsk(args, optimize_graph=optimize_graph))
+    dsks = [arg for arg in args2 if isinstance(arg, Mapping)]
+    args3 = [arg for arg in args2 if is_dask_collection(arg)]
+
+    dsk = dict(collections_to_dsk(args3, optimize_graph=optimize_graph))
     for d in dsks:
         dsk.update(d)
 
