@@ -10,12 +10,9 @@ except ImportError:
 
 import numpy as np
 import pandas as pd
-try:
-    from pandas.api.types import CategoricalDtype
-    _HAS_CDT = True
-except ImportError:
-    _HAS_CDT = False
-
+from pandas.api.types import (is_integer_dtype, is_float_dtype,
+                              is_object_dtype, is_datetime64_any_dtype,
+                              CategoricalDtype)
 
 from ...bytes import read_bytes, open_files
 from ...bytes.compression import seekable_files, files as cfiles
@@ -23,17 +20,10 @@ from ...compatibility import PY2, PY3, Mapping, unicode
 from ...delayed import delayed
 from ...utils import asciitable, parse_bytes
 
-from ..utils import clear_known_categories, PANDAS_VERSION
+from ..utils import clear_known_categories
 
 from .io import from_delayed
 
-if PANDAS_VERSION >= '0.20.0':
-    from pandas.api.types import (is_integer_dtype, is_float_dtype,
-                                  is_object_dtype, is_datetime64_any_dtype)
-else:
-    from pandas.types.common import (is_integer_dtype, is_float_dtype,
-                                     is_object_dtype, is_datetime64_any_dtype)
-
 
 def pandas_read_text(reader, b, header, kwargs, dtypes=None, columns=None,
                      write_header=True, enforce=False, path=None):
@@ -204,19 +194,17 @@ def text_blocks_to_pandas(reader, block_lists, header, head, kwargs,
 
     known_categoricals = []
     unknown_categoricals = categoricals
-
-    if _HAS_CDT:
-        if isinstance(specified_dtypes, Mapping):
-            known_categoricals = [
-                k for k in categoricals
-                if isinstance(specified_dtypes.get(k), CategoricalDtype) and
-                specified_dtypes.get(k).categories is not None
-            ]
-            unknown_categoricals = categoricals.difference(known_categoricals)
-        elif isinstance(specified_dtypes, CategoricalDtype):
-            if specified_dtypes.categories is None:
-                known_categoricals = []
-                unknown_categoricals = categoricals
+    if isinstance(specified_dtypes, Mapping):
+        known_categoricals = [
+            k for k in categoricals
+            if isinstance(specified_dtypes.get(k), CategoricalDtype) and
+            specified_dtypes.get(k).categories is not None
+        ]
+        unknown_categoricals = categoricals.difference(known_categoricals)
+    elif (isinstance(specified_dtypes, CategoricalDtype) and
+          specified_dtypes.categories is None):
+        known_categoricals = []
+        unknown_categoricals = categoricals
 
     # Fixup the dtypes
     for k in unknown_categoricals:
