@@ -8,7 +8,6 @@ import pandas as pd
 import dask.dataframe as dd
 from dask.dataframe.utils import (
     assert_eq, assert_dask_graph, make_meta, HAS_INT_NA,
-    PANDAS_GT_0240
 )
 
 
@@ -1007,13 +1006,6 @@ def test_reductions_frame_dtypes():
 
     result = ddf.mean()
     expected = df.mean()
-
-    if PANDAS_GT_0240:
-        # https://github.com/pandas-dev/pandas/issues/24752
-        # It's not clear whether this will be included by
-        # default.
-        expected = expected.drop('dt').astype(float)
-
     assert_eq(expected, result)
 
     assert_eq(df._get_numeric_data(), ddf._get_numeric_data())
