@@ -8,7 +8,8 @@ try:  # PyPy does not support sys.getsizeof
     sys.getsizeof(1)
     getsizeof = sys.getsizeof
 except (AttributeError, TypeError):  # Monkey patch
-    getsizeof = lambda x: 100
+    def getsizeof(x):
+        return 100
 
 
 sizeof = Dispatch(name='sizeof')
@@ -27,6 +28,15 @@ def sizeof_python_collection(seq):
     return getsizeof(seq) + sum(map(sizeof, seq))
 
 
+@sizeof.register_lazy("cupy")
+def register_cupy():
+    import cupy
+
+    @sizeof.register(cupy.ndarray)
+    def sizeof_cupy_ndarray(x):
+        return int(x.nbytes)
+
+
 @sizeof.register_lazy("numpy")
 def register_numpy():
     import numpy as np
@@ -39,29 +49,39 @@ def register_numpy():
 @sizeof.register_lazy("pandas")
 def register_pandas():
     import pandas as pd
+    import numpy as np
+
+    def object_size(x):
+        if not len(x):
+            return 0
+        sample = np.random.choice(x, size=20, replace=True)
+        sample = list(map(sizeof, sample))
+        return sum(sample) / 20 * len(x)
 
     @sizeof.register(pd.DataFrame)
     def sizeof_pandas_dataframe(df):
-        p = int(df.memory_usage(index=True).sum())
-        obj = int((df.dtypes == object).sum() * len(df) * 100)
-        if df.index.dtype == object:
-            obj += len(df) * 100
-        return int(p + obj) + 1000
+        p = sizeof(df.index)
+        for name, col in df.iteritems():
+            p += col.memory_usage(index=False)
+            if col.dtype == object:
+                p += object_size(col._values)
+        return int(p) + 1000
 
     @sizeof.register(pd.Series)
     def sizeof_pandas_series(s):
         p = int(s.memory_usage(index=True))
         if s.dtype == object:
-            p += len(s) * 100
+            p += object_size(s._values)
         if s.index.dtype == object:
-            p += len(s) * 100
+            p += object_size(s.index)
         return int(p) + 1000
 
     @sizeof.register(pd.Index)
     def sizeof_pandas_index(i):
         p = int(i.memory_usage())
-        obj = len(i) * 100 if i.dtype == object else 0
-        return int(p + obj) + 1000
+        if i.dtype == object:
+            p += object_size(i)
+        return int(p) + 1000
 
 
 @sizeof.register_lazy("scipy")
